#
# Compare to fig 6, of Hogg, D. W., "Distance measures in cosmology",
#   astro-ph/9905116
#
# Note:
#   currently only do the lookback time, not the age of the universe
#   curves
#

use strict;

use PDL;
use PDL::Graphics::PGPLOT;
use PGPLOT;

use blib;
use PDL::Astro::Cosmology;

# cosmologies - h0 is irrelevant here

my $a = new PDL::Astro::Cosmology { matter =>   1.0, lambda =>  0.0, h0 => 0.0 };
my $b = new PDL::Astro::Cosmology { matter =>  0.05, lambda =>  0.0, h0 => 0.0 };
my $c = new PDL::Astro::Cosmology { matter =>   0.2, lambda =>  0.8, h0 => 0.0 };

# z range
my $z = 0.1 * sequence(51);

# calculate the normalised lookback times
my $d_a = $a->lookback_time( $z );
my $d_b = $b->lookback_time( $z );
my $d_c = $c->lookback_time( $z );

# plot the graph
dev;

env 0, 5, 0, 1.2;
pglabel "redshift z", "lookback time t\\dL\\u/t\\dH\\u", "";

hold;

line $z, $d_a, { LINESTYLE => 'solid' };
line $z, $d_b, { LINESTYLE => 'dotted' };
line $z, $d_c, { LINESTYLE => 'dashed' };

release;

## End of the test
exit;

